X-Git-Url: https://git.openstreetmap.org./rails.git/blobdiff_plain/f735b073093bb4611da54530fc8e749554ccda7d..396f2e28dd27d514f7882c3918103b12764038de:/test/controllers/relation_controller_test.rb
diff --git a/test/controllers/relation_controller_test.rb b/test/controllers/relation_controller_test.rb
index 5ecd18fc7..afdab1bf2 100644
--- a/test/controllers/relation_controller_test.rb
+++ b/test/controllers/relation_controller_test.rb
@@ -2,8 +2,6 @@ require "test_helper"
require "relation_controller"
class RelationControllerTest < ActionController::TestCase
- api_fixtures
-
##
# test all routes which lead to this controller
def test_routes
@@ -52,11 +50,11 @@ class RelationControllerTest < ActionController::TestCase
def test_read
# check that a visible relation is returned properly
- get :read, :id => current_relations(:visible_relation).id
+ get :read, :id => create(:relation).id
assert_response :success
# check that an invisible relation is not returned
- get :read, :id => current_relations(:invisible_relation).id
+ get :read, :id => create(:relation, :deleted).id
assert_response :gone
# check chat a non-existent relation is not returned
@@ -153,10 +151,10 @@ class RelationControllerTest < ActionController::TestCase
get :full, :id => 999999
assert_response :not_found
- get :full, :id => current_relations(:invisible_relation).id
+ get :full, :id => create(:relation, :deleted).id
assert_response :gone
- get :full, :id => current_relations(:visible_relation).id
+ get :full, :id => create(:relation).id
assert_response :success
# FIXME: check whether this contains the stuff we want!
end
@@ -164,6 +162,12 @@ class RelationControllerTest < ActionController::TestCase
##
# test fetching multiple relations
def test_relations
+ relation1 = create(:relation)
+ relation2 = create(:relation, :deleted)
+ relation3 = create(:relation, :with_history, :version => 2)
+ relation4 = create(:relation, :with_history, :version => 2)
+ relation4.old_relations.find_by(:version => 1).redact!(create(:redaction))
+
# check error when no parameter provided
get :relations
assert_response :bad_request
@@ -173,18 +177,18 @@ class RelationControllerTest < ActionController::TestCase
assert_response :bad_request
# test a working call
- get :relations, :relations => "1,2,4,7"
+ get :relations, :relations => "#{relation1.id},#{relation2.id},#{relation3.id},#{relation4.id}"
assert_response :success
assert_select "osm" do
assert_select "relation", :count => 4
- assert_select "relation[id='1'][visible='true']", :count => 1
- assert_select "relation[id='2'][visible='false']", :count => 1
- assert_select "relation[id='4'][visible='true']", :count => 1
- assert_select "relation[id='7'][visible='true']", :count => 1
+ assert_select "relation[id='#{relation1.id}'][visible='true']", :count => 1
+ assert_select "relation[id='#{relation2.id}'][visible='false']", :count => 1
+ assert_select "relation[id='#{relation3.id}'][visible='true']", :count => 1
+ assert_select "relation[id='#{relation4.id}'][visible='true']", :count => 1
end
# check error when a non-existent relation is included
- get :relations, :relations => "1,2,4,7,400"
+ get :relations, :relations => "#{relation1.id},#{relation2.id},#{relation3.id},#{relation4.id},400"
assert_response :not_found
end
@@ -629,11 +633,18 @@ class RelationControllerTest < ActionController::TestCase
# when a relation's tag is modified then it should put the bounding
# box of all its members into the changeset.
def test_tag_modify_bounding_box
- # in current fixtures, relation 5 contains nodes 3 and 5 (node 3
- # indirectly via way 3), so the bbox should be [3,3,5,5].
+ relation = create(:relation)
+ node1 = create(:node, :lat => 3, :lon => 3)
+ node2 = create(:node, :lat => 5, :lon => 5)
+ way = create(:way)
+ create(:way_node, :way => way, :node => node1)
+ create(:relation_member, :relation => relation, :member => way)
+ create(:relation_member, :relation => relation, :member => node2)
+ # the relation contains nodes1 and node2 (node1
+ # indirectly via the way), so the bbox should be [3,3,5,5].
check_changeset_modify(BoundingBox.new(3, 3, 5, 5)) do |changeset_id|
# add a tag to an existing relation
- relation_xml = current_relations(:visible_relation).to_xml
+ relation_xml = relation.to_xml
relation_element = relation_xml.find("//osm/relation").first
new_tag = XML::Node.new("tag")
new_tag["k"] = "some_new_tag"
@@ -645,7 +656,7 @@ class RelationControllerTest < ActionController::TestCase
# upload the change
content relation_xml
- put :update, :id => current_relations(:visible_relation).id
+ put :update, :id => relation.id
assert_response :success, "can't update relation for tag/bbox test"
end
end
@@ -694,11 +705,17 @@ class RelationControllerTest < ActionController::TestCase
# remove a member from a relation and check the bounding box is
# only that element.
def test_remove_member_bounding_box
+ relation = create(:relation)
+ node1 = create(:node, :lat => 3, :lon => 3)
+ node2 = create(:node, :lat => 5, :lon => 5)
+ create(:relation_member, :relation => relation, :member => node1)
+ create(:relation_member, :relation => relation, :member => node2)
+
check_changeset_modify(BoundingBox.new(5, 5, 5, 5)) do |changeset_id|
# remove node 5 (5,5) from an existing relation
- relation_xml = current_relations(:visible_relation).to_xml
+ relation_xml = relation.to_xml
relation_xml
- .find("//osm/relation/member[@type='node'][@ref='5']")
+ .find("//osm/relation/member[@type='node'][@ref='#{node2.id}']")
.first.remove!
# update changeset ID to point to new changeset
@@ -706,7 +723,7 @@ class RelationControllerTest < ActionController::TestCase
# upload the change
content relation_xml
- put :update, :id => current_relations(:visible_relation).id
+ put :update, :id => relation.id
assert_response :success, "can't update relation for remove node/bbox test"
end
end
@@ -724,15 +741,15 @@ class RelationControllerTest < ActionController::TestCase
basic_authorization(user.email, "test")
- doc_str = <
-
-
-
-
-
-
-
+ doc_str = <
+
+
+
+
+
+
+
OSM
doc = XML::Parser.string(doc_str).parse
@@ -784,15 +801,15 @@ OSM
node1 = create(:node)
node2 = create(:node)
- doc_str = <
-
-
-
-
-
-
-
+ doc_str = <
+
+
+
+
+
+
+
OSM
doc = XML::Parser.string(doc_str).parse
@@ -827,15 +844,15 @@ OSM
node3 = create(:node)
node4 = create(:node)
- doc_str = <
-
-
-
-
-
-
-
+ doc_str = <
+
+
+
+
+
+
+
OSM
doc = XML::Parser.string(doc_str).parse
basic_authorization(user.email, "test")
@@ -862,8 +879,16 @@ OSM
# remove all the members from a relation. the result is pretty useless, but
# still technically valid.
def test_remove_all_members
+ relation = create(:relation)
+ node1 = create(:node, :lat => 3, :lon => 3)
+ node2 = create(:node, :lat => 5, :lon => 5)
+ way = create(:way)
+ create(:way_node, :way => way, :node => node1)
+ create(:relation_member, :relation => relation, :member => way)
+ create(:relation_member, :relation => relation, :member => node2)
+
check_changeset_modify(BoundingBox.new(3, 3, 5, 5)) do |changeset_id|
- relation_xml = current_relations(:visible_relation).to_xml
+ relation_xml = relation.to_xml
relation_xml
.find("//osm/relation/member")
.each(&:remove!)
@@ -873,9 +898,9 @@ OSM
# upload the change
content relation_xml
- put :update, :id => current_relations(:visible_relation).id
+ put :update, :id => relation.id
assert_response :success, "can't update relation for remove all members test"
- checkrelation = Relation.find(current_relations(:visible_relation).id)
+ checkrelation = Relation.find(relation.id)
assert_not_nil(checkrelation,
"uploaded relation not found in database after upload")
assert_equal(0, checkrelation.members.length,
@@ -942,10 +967,10 @@ OSM
assert_response :success, "can't re-read changeset for modify test"
assert_select "osm>changeset", 1, "Changeset element doesn't exist in #{@response.body}"
assert_select "osm>changeset[id='#{changeset_id}']", 1, "Changeset id=#{changeset_id} doesn't exist in #{@response.body}"
- assert_select "osm>changeset[min_lon='#{bbox.min_lon}']", 1, "Changeset min_lon wrong in #{@response.body}"
- assert_select "osm>changeset[min_lat='#{bbox.min_lat}']", 1, "Changeset min_lat wrong in #{@response.body}"
- assert_select "osm>changeset[max_lon='#{bbox.max_lon}']", 1, "Changeset max_lon wrong in #{@response.body}"
- assert_select "osm>changeset[max_lat='#{bbox.max_lat}']", 1, "Changeset max_lat wrong in #{@response.body}"
+ assert_select "osm>changeset[min_lon='#{format('%.7f', bbox.min_lon)}']", 1, "Changeset min_lon wrong in #{@response.body}"
+ assert_select "osm>changeset[min_lat='#{format('%.7f', bbox.min_lat)}']", 1, "Changeset min_lat wrong in #{@response.body}"
+ assert_select "osm>changeset[max_lon='#{format('%.7f', bbox.max_lon)}']", 1, "Changeset max_lon wrong in #{@response.body}"
+ assert_select "osm>changeset[max_lat='#{format('%.7f', bbox.max_lat)}']", 1, "Changeset max_lat wrong in #{@response.body}"
end
end